# saturnin-core

## Saturnin core services

[![PyPI - Version](https://img.shields.io/pypi/v/saturnin-core.svg)](https://pypi.org/project/saturnin-core)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/saturnin-core.svg)](https://pypi.org/project/saturnin-core)
[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch)

The core set of services for Saturnin currently contains next services:

- Text file reader microservice - `saturnin.text.reader`
- Text file writer microservice - `saturnin.text.writer`
- Text line filter microservice - `saturnin.text.linefilter`
- Binary data file reader microservice - `saturnin.binary.reader`
- Binary data file writer microservice - `saturnin.binary.writer`
- Protobuf printer microservice - `saturnin.proto.printer`
- Protobuf filter microservice - `saturnin.proto.filter`
- Protobuf aggregator microservice - `saturnin.proto.aggregator`
- Firebird log from server provider microservice - `saturnin.firebird.log.fromsrv`
- Firebird log parser microservice - `saturnin.firebird.log.parser`
- Firebird trace parser microservice - `saturnin.firebird.trace.parser`
- Firebird trace session provider microservice - `saturnin.firebird.trace.session`

For information how to use these services, see [Saturnin CORE documentation](https://saturnin-core.rtfd.io/).

-----

**Table of Contents**

- [License](#license)
- [Installation](#installation)
- [Documentation](#documentation)

## License

`saturnin` and `saturnin-core` are distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Installation

For installation instructions, see the [Saturnin documentation](https://saturnin.rtfd.io).

## Documentation

Documentation related to Saturnin:

- [Firebird Butler](https://firebird-butler.rtfd.io/)
- [Saturnin](https://saturnin.rtfd.io/)
- [Saturnin CORE](https://saturnin-core.rtfd.io/) services
- [Saturnin SDK](https://saturnin-sdk.rtfd.io/)
